@@ -317,6 +317,9 @@ class Database(object):
         .. seealso:: `HTTP Bulk Document API <http://wiki.apache.org/couchdb/HTTP_Bulk_Document_API>`
         
         """
+        # we definitely need a list here, not any iterable, or groupby will fail
+        docs = list(docs)
+                
         def is_id(doc):
             return '_id' in doc
             
@@ -389,7 +392,7 @@ class Database(object):
             docid = doc['_id']
         
         if dest is None:
-            destinatrion = self.server.next_uuid(count=1)   
+            destination = self.server.next_uuid(count=1)   
         elif isinstance(dest, basestring):
             if dest in self:
                 dest = self.get(dest)['_rev']
@@ -473,7 +476,6 @@ class Database(object):
         """
 
         headers = {}
-        headers.setdefault('Content-Type', 'text/plain')
         
         content = content or ''
         if content and chunked:
@@ -723,8 +725,7 @@ class View(ViewInterface):
     def __init__(self, db, view_path, wrapper=None):
         ViewInterface.__init__(self, db, wrapper=wrapper)
         self.view_path = view_path
-        
-        
+              
     def _exec(self, **params):
         if 'keys' in params:
             keys = params.pop('keys')
@@ -732,7 +733,6 @@ class View(ViewInterface):
         else:
             return self._db.res.get(self.view_path, **params)
             
-
 class TempView(ViewInterface):
     def __init__(self, db, design, wrapper=None):
         ViewInterface.__init__(self, db, wrapper=wrapper)
