@@ -35,4 +35,7 @@ class NoResultFound(Exception):
     
 class ReservedWordError(Exception):
     """ exception raised when a reserved word
-    is used in Document schema """
\ No newline at end of file
+    is used in Document schema """
+    
+class DocsPathNotFound(Exception):
+    """ exception raised when path given for docs isn't found """
\ No newline at end of file
