@@ -32,26 +32,33 @@ from hashlib import md5
 from couchdbkit.utils import read_file, read_json, to_bytestring
 
 def package_shows(doc, funcs, app_dir, objs, verbose=False):
-   apply_lib(doc, funcs, app_dir, objs, verbose=verbose)
+    apply_lib(doc, funcs, app_dir, objs, verbose=verbose)
          
 def package_views(doc, views, app_dir, objs, verbose=False):
-   for view, funcs in views.iteritems():
-       apply_lib(doc, funcs, app_dir, objs, verbose=verbose)
-
+    for view, funcs in views.iteritems():
+        try:
+            apply_lib(doc, funcs, app_dir, objs, verbose=verbose)
+        except AttributeError, e:
+            # malformated views
+            msg = """View %s is invalid. Folder structure is: 
+designpathg/designname/views/viewname/{map,reduce}.js""" % view
+            print >>sys.stderr, msg
+            sys.exit(-1)
+                
+        
 def apply_lib(doc, funcs, app_dir, objs, verbose=False):
     for k, v in funcs.iteritems():
-        if not isinstance(v, basestring):
-            continue
-        old_v = v
-        try:
-            funcs[k] = run_json_macros(doc, 
-                run_code_macros(v, app_dir, verbose=verbose), 
-                app_dir, verbose=verbose)
-        except ValueError, e:
-            print >>sys.stderr, "Error running !code or !json on function \"%s\": %s" % (k, e)
-            sys.exit(-1)
-        if old_v != funcs[k]:
-            objs[md5(to_bytestring(funcs[k])).hexdigest()] = old_v
+        if isinstance(v, basestring):
+            old_v = v
+            try:
+                funcs[k] = run_json_macros(doc, 
+                    run_code_macros(v, app_dir, verbose=verbose), 
+                    app_dir, verbose=verbose)
+            except ValueError, e:
+                print >>sys.stderr, "Error running !code or !json on function \"%s\": %s" % (k, e)
+                sys.exit(-1)
+            if old_v != funcs[k]:
+                objs[md5(to_bytestring(funcs[k])).hexdigest()] = old_v
            
 
 def run_code_macros(f_string, app_dir, verbose=False):
