@@ -17,9 +17,11 @@
 
 import threading
 
-from couchdbkit.client import Database
+from couchdbkit.client import Server, Database
 
 def create_session(server, db_name, scoped_func=None):
+    if isinstance(server, basestring):
+        server = Server(server)
     return Session(server, db_name, scoped_func)
 
 class Session(object):
@@ -53,6 +55,9 @@ class Session(object):
         self.dbname = dbname
         self.registry = ScopedRegistry(self.session_factory,
                 scoped_func)
+                
+    def __repr__(self):
+        return "<%s %s>" % (self.__class__.__name__, self.dbname)
     
     def __call__(self, document):
         if not hasattr(document, '_db'):
@@ -61,7 +66,13 @@ class Session(object):
         db = self.registry()
         document._db = db
         return document
-
+        
+    def contain(self, *docs):
+        """ add db session to all DocumentBase instance """
+        for doc in docs:
+            if hasattr(doc, '_db'):
+                doc._db = self
+        
     def __getattr__(self, key):
         db = self.registry()
         if not key.startswith('_') and key not in dir(self) \
@@ -77,9 +88,9 @@ class Session(object):
         db = self.registry()
         return db.__contains__(docid)
         
-    def __getitem__(self, id):
+    def __getitem__(self, docid):
         db = self.registry()
-        return db.get(id)
+        return db.__getitem__(docid)
         
     def __setitem__(self, docid, doc):
         db = self.registry()
@@ -87,7 +98,7 @@ class Session(object):
         
     def __delitem__(self, docid):
         db = self.registry()
-        return db.__delitem__(docid, doc)
+        return db.__delitem__(docid)
 
     def __iter__(self):
         db = self.registry()
